==> qtjambi-statemachine-6.2.1-sources.jar: io/qt/statemachine/QFinalState.java <==
package io.qt.statemachine;


/**
 * <p>Java wrapper for Qt class QFinalState</p>
 */
public class QFinalState extends io.qt.statemachine.QAbstractState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFinalState.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFinalState(io.qt.statemachine.QState)}
     *  with <code>parent = null</code>.</p>
     */
    public QFinalState() {
        this((io.qt.statemachine.QState)null);
    }
    
    public QFinalState(io.qt.statemachine.QState parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFinalState instance, io.qt.statemachine.QState parent);
    
    @io.qt.QtUninvokable
    public boolean event(io.qt.core.QEvent e){
        return event_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(e));
    }
    
    @io.qt.QtUninvokable
    private native boolean event_native_QEvent_ptr(long __this__nativeId, long e);
    
    @io.qt.QtUninvokable
    protected void onEntry(io.qt.core.QEvent event){
        onEntry_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void onEntry_native_QEvent_ptr(long __this__nativeId, long event);
    
    @io.qt.QtUninvokable
    protected void onExit(io.qt.core.QEvent event){
        onExit_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void onExit_native_QEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QFinalState(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QFinalState(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QFinalState instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-statemachine-6.5.0-sources.jar: io/qt/statemachine/QFinalState.java <==
package io.qt.statemachine;

import io.qt.*;


/**
 * <p>Final state</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qfinalstate.html">QFinalState</a></p>
 */
public class QFinalState extends io.qt.statemachine.QAbstractState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFinalState.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFinalState(io.qt.statemachine.QState)}
     *  with <code>parent = null</code>.</p>
     */
    public QFinalState() {
        this((io.qt.statemachine.QState)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qfinalstate.html#QFinalState">QFinalState::QFinalState(QState*)</a></p>
     */
    public QFinalState(io.qt.statemachine.@Nullable QState parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFinalState instance, io.qt.statemachine.QState parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qobject.html#event">QObject::event(QEvent*)</a></p>
     */
    @QtUninvokable
    public boolean event(io.qt.core.@Nullable QEvent e){
        return event_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(e));
    }
    
    @QtUninvokable
    private native boolean event_native_QEvent_ptr(long __this__nativeId, long e);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractstate.html#onEntry">QAbstractState::onEntry(QEvent*)</a></p>
     */
    @QtUninvokable
    protected void onEntry(io.qt.core.@Nullable QEvent event){
        onEntry_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native void onEntry_native_QEvent_ptr(long __this__nativeId, long event);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstractstate.html#onExit">QAbstractState::onExit(QEvent*)</a></p>
     */
    @QtUninvokable
    protected void onExit(io.qt.core.@Nullable QEvent event){
        onExit_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @QtUninvokable
    private native void onExit_native_QEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QFinalState(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFinalState(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFinalState instance, QDeclarativeConstructor constructor);
    
}
